@@ -6,7 +6,7 @@ VERSION=$(cat share/torbrowser-launcher/version)
 rm -r build dist
 
 # build binary package
-python3 setup.py bdist_rpm --requires="python3-qt5, python3-gpg, python3-requests, python3-pysocks, python3-packaging, gnupg2, dbus-glib"
+python3 setup.py bdist_rpm --requires="python3-pyside6, python3-gpg, python3-requests, python3-setuptools, python3-pysocks, python3-packaging, gnupg2, dbus-glib"
 
 # install it
 echo ""
