@@ -1,8 +1,9 @@
 """
 Tor Browser Launcher
-https://github.com/micahflee/torbrowser-launcher/
+https://gitlab.torproject.org/tpo/applications/torbrowser-launcher/
 
-Copyright (c) 2013-2021 Micah Lee <micah@micahflee.com>
+Copyright (c) 2013-2023 Micah Lee <micah@micahflee.com>
+Copyright (c) 2024 Tor Project
 
 Permission is hereby granted, free of charge, to any person
 obtaining a copy of this software and associated documentation
@@ -31,7 +32,7 @@ import sys
 import argparse
 import signal
 
-from PyQt5 import QtCore, QtWidgets
+from PySide6 import QtWidgets
 
 from .common import Common, SHARE
 from .settings import Settings
@@ -44,7 +45,6 @@ class Application(QtWidgets.QApplication):
     """
 
     def __init__(self):
-        self.setAttribute(QtCore.Qt.AA_X11InitThreads, True)
         QtWidgets.QApplication.__init__(self, sys.argv)
         self.installEventFilter(self)
 
@@ -64,18 +64,25 @@ def main():
     settings = bool(args.settings)
     url_list = args.url
 
+    # Set the TORBROWSER_LAUNCHER env variable to make it easier to
+    # detect that torbrowser-launcher is being used
+    os.environ["TORBROWSER_LAUNCHER"] = "1"
+
     # Load the version and print the banner
     with open(os.path.join(SHARE, "version")) as buf:
         tor_browser_launcher_version = buf.read().strip()
 
     print(_("Tor Browser Launcher"))
-    print(_("By Micah Lee, licensed under MIT"))
+    print(_("By Micah Lee & Tor Project, licensed under MIT"))
     print(_("version {0}").format(tor_browser_launcher_version))
-    print("https://github.com/micahflee/torbrowser-launcher")
+    print("https://gitlab.torproject.org/tpo/applications/torbrowser-launcher/")
 
     common = Common(tor_browser_launcher_version)
     app = Application()
 
+    if "WAYLAND_DISPLAY" in os.environ:
+        app.setDesktopFileName("org.torproject.torbrowser-launcher")
+
     # Open the window
     gui = None
 
@@ -87,11 +94,11 @@ def main():
         gui = Launcher(common, app, url_list)
 
     # Center the window
-    desktop = app.desktop()
+    screen_size = app.primaryScreen().size()
     window_size = gui.size()
     gui.move(
-        (desktop.width() - window_size.width()) / 2,
-        (desktop.height() - window_size.height()) / 2,
+        (screen_size.width() - window_size.width()) // 2,
+        (screen_size.height() - window_size.height()) // 2,
     )
     gui.show()
 
