@@ -1,8 +1,9 @@
 """
 Tor Browser Launcher
-https://github.com/micahflee/torbrowser-launcher/
+https://gitlab.torproject.org/tpo/applications/torbrowser-launcher/
 
-Copyright (c) 2013-2021 Micah Lee <micah@micahflee.com>
+Copyright (c) 2013-2023 Micah Lee <micah@micahflee.com>
+Copyright (c) 2024 Tor Project
 
 Permission is hereby granted, free of charge, to any person
 obtaining a copy of this software and associated documentation
@@ -39,7 +40,7 @@ import shutil
 import xml.etree.ElementTree as ET
 from packaging import version
 
-from PyQt5 import QtCore, QtWidgets, QtGui
+from PySide6 import QtCore, QtWidgets, QtGui
 
 
 class TryStableException(Exception):
@@ -70,9 +71,10 @@ class Launcher(QtWidgets.QMainWindow):
 
         self.url_list = url_list
         self.force_redownload = False
+        self._threads = []
 
         # This is the current version of Tor Browser, which should get updated with every release
-        self.min_version = "12.0"
+        self.min_version = "13.0"
 
         # Init launcher
         self.set_state(None, "", [])
@@ -349,9 +351,11 @@ class Launcher(QtWidgets.QMainWindow):
         t.progress_update.connect(progress_update)
         t.download_complete.connect(download_complete)
         t.download_error.connect(download_error)
+        self._threads.append(t)
         t.start()
         time.sleep(0.2)
 
+
     def try_default_mirror(self):
         # change mirror to default and relaunch TBL
         self.common.settings["mirror"] = self.common.default_mirror
@@ -407,7 +411,7 @@ class Launcher(QtWidgets.QMainWindow):
                 "A copy of the Tor Browser files you downloaded have been saved here:\n"
                 "{1}\n{2}\n\n"
                 "Click Start to refresh the keyring and try again. If the message persists report the above "
-                "error code here:\nhttps://github.com/micahflee/torbrowser-launcher/issues"
+                "error code here:\nhttps://gitlab.torproject.org/tpo/applications/torbrowser-launcher/-/issues/"
             )
             sigerror = sigerror.format(
                 message, backup_tarball_filename, backup_sig_filename
@@ -419,6 +423,7 @@ class Launcher(QtWidgets.QMainWindow):
         t = VerifyThread(self.common)
         t.error.connect(error)
         t.success.connect(success)
+        self._threads.append(t)
         t.start()
         time.sleep(0.2)
 
@@ -448,6 +453,7 @@ class Launcher(QtWidgets.QMainWindow):
         t = ExtractThread(self.common)
         t.error.connect(error)
         t.success.connect(success)
+        self._threads.append(t)
         t.start()
         time.sleep(0.2)
 
@@ -531,9 +537,9 @@ class DownloadThread(QtCore.QThread):
     Download a file in a separate thread.
     """
 
-    progress_update = QtCore.pyqtSignal(int, int)
-    download_complete = QtCore.pyqtSignal()
-    download_error = QtCore.pyqtSignal(str, str)
+    progress_update = QtCore.Signal(int, int)
+    download_complete = QtCore.Signal()
+    download_error = QtCore.Signal(str, str)
 
     def __init__(self, common, url, path):
         super(DownloadThread, self).__init__()
@@ -614,8 +620,8 @@ class VerifyThread(QtCore.QThread):
     Verify the signature in a separate thread
     """
 
-    success = QtCore.pyqtSignal()
-    error = QtCore.pyqtSignal(str)
+    success = QtCore.Signal()
+    error = QtCore.Signal(str)
 
     def __init__(self, common):
         super(VerifyThread, self).__init__()
@@ -656,8 +662,8 @@ class ExtractThread(QtCore.QThread):
     Extract the tarball in a separate thread
     """
 
-    success = QtCore.pyqtSignal()
-    error = QtCore.pyqtSignal()
+    success = QtCore.Signal()
+    error = QtCore.Signal()
 
     def __init__(self, common):
         super(ExtractThread, self).__init__()
